# Changelog

<!--next-version-placeholder-->

## v0.7.5 (2022-04-24)
### Feature
* **actions:** Support filters for process-check-result (fixes #4) ([`12be4c5`](https://github.com/joni1993/icinga2apic/commit/12be4c5f862b1af7f58b97ad25d7bb73f56b3db4))

### Fix
* **encoding:** Remove umlaut from name ([`d964e1d`](https://github.com/joni1993/icinga2apic/commit/d964e1d978e4c8d137edd501f4aa19040d10cb8e))
* **actions:** Allow to remove comments based on filter  ([`a74120f`](https://github.com/joni1993/icinga2apic/commit/a74120f9da026bf20383d644fdc88dc15b16b309))
